﻿using MathNet.Numerics.Statistics;
using System;
using System.Collections.Generic;
using System.Linq;

public static class Extension
{
    public static IEnumerable<TResult> ForEach<TArg1, TResult>(this IEnumerable<TArg1> enumeration, Func<TArg1, TResult> action)
    {
        foreach (TArg1 item in enumeration)
        {
            yield return action(item);
        }
    }

    public static (double, double) MeanAndStd(this IEnumerable<ClickData> data)
    {
        var xData = from item in data
                    select item.X;

        return (Statistics.Mean(xData), Statistics.PopulationStandardDeviation(xData));
    }

    public static IEnumerable<ClickData> NormalizeZscore(this IEnumerable<ClickData> data)
    {
        (double mean, double std) = data.MeanAndStd();

        foreach (ClickData item in data)
        {
            yield return new ClickData((item.X - mean) / std, item.Y);
        }
    }

}
